@@ -4,7 +4,7 @@ import warnings
 import numpy as np
 import pandas as pd
 
-from inspec_ai.utils.text_utils import str_as_list
+from inspec_ai.utils.text_utils import enumerate_elements_in_a_sentence
 from inspec_ai.analytics import telemetry_service
 
 
@@ -125,14 +125,14 @@ def _validate_inputs_have_the_same_length(inputs):
     input_lengths = [len(x) for x in inputs.values()]
 
     if not all(x == input_lengths[0] for x in input_lengths):
-        raise ValueError(f"The following provided inputs must contain the same number of elements: {str_as_list(list(inputs))}.")
+        raise ValueError(f"The following provided inputs must contain the same number of elements: {enumerate_elements_in_a_sentence(list(inputs))}.")
 
 
 def _validate_inputs_have_at_least_two_elements(inputs):
     input_lengths = [len(x) for x in inputs.values()]
 
     if not all(x >= 2 for x in input_lengths):
-        raise ValueError(f"The following provided inputs must contain at least 2 elements: {str_as_list(list(inputs))}.")
+        raise ValueError(f"The following provided inputs must contain at least 2 elements: {enumerate_elements_in_a_sentence(list(inputs))}.")
 
 
 def _validate_time_input(time):
